@@ -25,8 +25,8 @@
 #define CT_STR(x)		CT_STRINGIFY(x)
 
 #define CT_VERSION_MAJOR	1
-#define CT_VERSION_MINOR	5
-#define CT_VERSION_PATCH	0
+#define CT_VERSION_MINOR	6
+#define CT_VERSION_PATCH	2
 #define CT_VERSION		CT_STR(CT_VERSION_MAJOR) "." \
 				CT_STR(CT_VERSION_MINOR) "." \
 				CT_STR(CT_VERSION_PATCH)
@@ -64,11 +64,14 @@ void			 ct_unload_config(char *, struct ct_config *);
 char *ct_system_config(void);
 char *ct_user_config(void);
 char *ct_user_config_old(void);
+void ct_write_escaped(FILE *, const char *);
 void ct_write_config(struct ct_config *, FILE *, int, int);
 void ct_default_config(struct ct_config *);
 int ct_download_decode_and_save_certs(struct ct_config *);
+int ct_check_expired_certs(struct ct_config *);
 void ct_info_sig(evutil_socket_t fd, short event, void *vctx);
 
+
 /* Statistics */
 struct ct_statistics {
 	struct timeval		st_time_start;
@@ -201,6 +204,7 @@ struct ct_global_state {
 
 	int				 ct_cull_occurred;
 	int				 ct_dying;
+	int			 	 ct_cancelled;
 	struct ct_trans			*ct_fatal_trans;
 	int				 ct_errno;
 	/* XXX reasonable size? */
@@ -208,6 +212,7 @@ struct ct_global_state {
 };
 
 int		 ct_setup_state(struct ct_global_state **, struct ct_config *);
+void		 ct_cancel(struct ct_global_state *);
 
 /* File status */
 #define CT_S_STARTING		(0)
